.. py:currentmodule:: drdmannturb

Covariance Kernels
==================

.. autoclass:: drdmannturb.Covariance 
    :members: 

.. autoclass:: drdmannturb.VonKarmanCovariance
    :members:

.. autoclass:: drdmannturb.MannCovariance
    :members:

.. autoclass:: drdmannturb.NNCovariance
    :members: